==> create-expris-1.1.0.tgz: package/bin/cli.js <==
#!/usr/bin/env node

const figlet = require("figlet");
const chalk = require("chalk");
const gradient = require("gradient-string");
const { createSpinner } = require("nanospinner");
const { execSync } = require("child_process");
const inquirer = require("inquirer");

const sleep = (ms = 2000) => new Promise((r) => setTimeout(r, ms));

const runCmd = (cmd) => {
  try {
    execSync(`${cmd}`, { stdio: `inherit` });
  } catch (error) {
    console.log(chalk.bgRed(`Faild to execute ${cmd}`, error));
    return false;
  }
  return true;
};

async function welcome() {
  figlet.text(
    "Expris",
    {
      font: "Small Slant",
      horizontalLayout: "default",
      verticalLayout: "default",
      width: 80,
      whitespaceBreak: true,
    },
    function (err, data) {
      if (err) {
        console.log("Something went wrong...");
        console.dir(err);
        return;
      }
      console.log(gradient("orange", "pink")(data));
      console.log("thanks for using create-expris 🐇");
    }
  );
  await sleep();

  console.log(`
    ${chalk.bgCyan("ExpressJs x Prisma ORM ")} 
    Hi I am Aami Bhoot 👻  ${chalk.bgBlack(`⎣https://github.com/aamibhoot⎤ `)}.
    ${chalk.green(`ExpressJs`)} 🚀 ${chalk.bgGreen(
    `⎣ https://expressjs.com ⎤ `
  )}
    ${chalk.magenta(`PrismaORM`)} ✨ ${chalk.bgMagenta(
    `⎣ https://www.prisma.io ⎤`
  )}

  `);
}
let projectName;
let projectType;
async function askName() {
  const answers = await inquirer.prompt({
    name: "pkg_name",
    type: "input",
    message: "What do you name it?",
    default() {
      return "Project Name";
    },
  });

  projectName = answers.pkg_name;
}
async function selectType() {
  const answers = await inquirer.prompt({
    name: "type",
    type: "list",
    message: "How to you like your Expris to be \n",
    choices: ["Loaded w/ cool stuffs 🤯", "Blank 😷"],
  });

  projectType = answers.type;
}
async function downPkg1() {
  const initSpinner = createSpinner(
    `Creating your next awesome ${projectName} project with expris🐰 \n`
  ).start();
  const cloneCmd = runCmd(
    `git clone https://github.com/aamibhoot/expris.git ${projectName}`
  );
  if (!cloneCmd) process.exit(-1);
  initSpinner.success();
}
async function instPkg() {
  const pkgsSpinner = createSpinner(`Installing dependencies 🤹 \n`).start();
  const instPkgCmd = runCmd(`cd ${projectName} && npm install`);
  if (!instPkgCmd) process.exit(-1);
  pkgsSpinner.success();
}

async function downPkg2() {
  const initSpinner = createSpinner(
    `Creating your next awesome ${projectName} project with blank expris 🐰 \n`
  ).start();
  const cloneCmd = runCmd(
    `git clone https://github.com/aamibhoot/expris-blank.git ${projectName}`
  );
  if (!cloneCmd) process.exit(-1);
  initSpinner.success();
}
async function instPkg() {
  const pkgsSpinner = createSpinner(`Installing dependencies 🤹 \n`).start();
  const instPkgCmd = runCmd(`cd ${projectName} && npm install`);
  if (!instPkgCmd) process.exit(-1);
  pkgsSpinner.success();
}

async function prismaInit() {
  const prismaSpinner = createSpinner(`Initializing Prisma 🧮 \n`).start();
  const instPrisCmd = runCmd(`cd ${projectName} && npx prisma init`);
  if (!instPrisCmd) process.exit(-1);
  prismaSpinner.success();
  console.log(chalk.cyan("You are all ready to go 🎉"));
}

async function main() {
  console.clear();
  await welcome();
  await askName();
  await selectType();
  if (projectType === "Blank 😷") {
    await downPkg2();
  } else await downPkg1();

  await instPkg();
  runCmd(
    `cd ${projectName} && npm uninstall figlet inquirer nanospinner gradient-string`
  );
  await prismaInit();
}
main();

==> create-expris-1.1.3.tgz: package/bin/cli.js <==
#!/usr/bin/env node

const figlet = require("figlet");
const chalk = require("chalk");
const gradient = require("gradient-string");
const { createSpinner } = require("nanospinner");
const { execSync } = require("child_process");
const inquirer = require("inquirer");

const sleep = (ms = 2000) => new Promise((r) => setTimeout(r, ms));

const runCmd = (cmd) => {
  try {
    execSync(`${cmd}`, { stdio: `inherit` });
  } catch (error) {
    console.log(chalk.bgRed(`Faild to execute ${cmd}`, error));
    return false;
  }
  return true;
};

async function welcome() {
  figlet.text(
    "Expris",
    {
      font: "Small Slant",
      horizontalLayout: "default",
      verticalLayout: "default",
      width: 80,
      whitespaceBreak: true,
    },
    function (err, data) {
      if (err) {
        console.log("Something went wrong...");
        console.dir(err);
        return;
      }
      console.log(gradient("orange", "pink")(data));
      console.log("thanks for using create-expris 🐇");
    }
  );
  await sleep();

  console.log(`
    ${chalk.bgCyan("ExpressJs x Prisma ORM ")} 
    Hi I am Aami Bhoot 👻  ${chalk.bgBlack(`⎣https://github.com/aamibhoot⎤`)}
    ${chalk.green(`ExpressJs`)} 🚀 ${chalk.bgGreen(
    `⎣ https://expressjs.com ⎤ `
  )}
    ${chalk.magenta(`PrismaORM`)} ✨ ${chalk.bgMagenta(
    `⎣ https://www.prisma.io ⎤`
  )}

  `);
}
let projectName;
let projectType;
async function askName() {
  const answers = await inquirer.prompt({
    name: "pkg_name",
    type: "input",
    message: "What do you name it?",
    default() {
      return "Project Name";
    },
  });

  projectName = answers.pkg_name;
}
async function selectType() {
  const answers = await inquirer.prompt({
    name: "type",
    type: "list",
    message: "How to you like your Expris to be \n",
    choices: ["Loaded w/ cool stuffs 🤯", "Blank 😷"],
  });

  projectType = answers.type;
}
async function downPkg1() {
  const initSpinner = createSpinner(
    `Creating your next awesome ${projectName} project with expris🐰 \n`
  ).start();
  const cloneCmd = runCmd(
    `git clone https://github.com/aamibhoot/expris.git ${projectName}`
  );
  if (!cloneCmd) process.exit(-1);
  initSpinner.success();
}
async function instPkg() {
  const pkgsSpinner = createSpinner(`Installing dependencies 🤹 \n`).start();
  const instPkgCmd = runCmd(`cd ${projectName} && npm install`);
  if (!instPkgCmd) process.exit(-1);
  pkgsSpinner.success();
}

async function downPkg2() {
  const initSpinner = createSpinner(
    `Creating your next awesome ${projectName} project with blank expris 🐰 \n`
  ).start();
  const cloneCmd = runCmd(
    `git clone https://github.com/aamibhoot/expris-blank.git ${projectName}`
  );
  if (!cloneCmd) process.exit(-1);
  initSpinner.success();
}
async function instPkg() {
  const pkgsSpinner = createSpinner(`Installing dependencies 🤹 \n`).start();
  const instPkgCmd = runCmd(`cd ${projectName} && npm install`);
  if (!instPkgCmd) process.exit(-1);
  pkgsSpinner.success();
}

async function prismaInit() {
  const prismaSpinner = createSpinner(`Initializing Prisma 🧮 \n`).start();
  const instPrisCmd = runCmd(`cd ${projectName} && npx prisma init`);
  if (!instPrisCmd) process.exit(-1);
  prismaSpinner.success();
  console.log(chalk.cyan("You are all ready to go 🎉"));
}

async function main() {
  console.clear();
  await welcome();
  await askName();
  await selectType();
  if (projectType === "Blank 😷") {
    await downPkg2();
  } else await downPkg1();

  await instPkg();
  runCmd(`cd ${projectName} && npx npe expris-${projectName}`);
  runCmd(
    `cd ${projectName} && npm uninstall figlet inquirer nanospinner gradient-string npe`
  );
  await prismaInit();
}
main();
